@@ -7,7 +7,7 @@ from wagtail.admin.site_summary import SummaryItem
 try:
     import uwsgi
 except ImportError:
-    pass
+    uwsgi = None
 
 
 class UwsgiSummaryItem(SummaryItem):
